tmd_nodeeditor
==============

A Node Editor Library using PyQt5 Specialized in TMD
-----------------------------------------------------

A package that allows building simple nodes, sockets, and edges.

Installation
------------

::

    pip install tmd_nodeeditor

Usage
-----

[Include any usage instructions or examples here.]

